%define anolis_release 4

Summary:	REALTIMEKIT Realtime Policy and Watchdog Daemon
Name:		rtkit
Epoch:		1
Version:	0.11
Release:	%{anolis_release}%{?dist}

# The daemon itself is GPL3 licensed, and the client library is BSD licensed.
License:	GPLv3+ and BSD
URL:		http://git.0pointer.net/%{name}.git/
Source0:	https://0pointer.de/public/%{name}-%{version}.tar.xz

BuildRequires:  autoconf automake libtool make
BuildRequires:  dbus-devel >= 1.2
BuildRequires:  libcap-devel
BuildRequires:  polkit-devel >= 0.92
BuildRequires:  systemd-devel

Requires:	dbus
Requires:       polkit >= 0.92

Patch0:         0000-rtkit-mq_getattr.patch
Patch1:         0001-SECURITY-Pass-uid-of-caller-to-polkit.patch
Patch2:         0002-rtkit-controlgroup.patch

# Temporarily disable -Werror=format-security since it breaks the build
Patch3:         0003-format-security.patch

Patch4:         0004-Fix-borked-error-check.patch
Patch5:         0005-systemd-update-sd-daemon.-ch.patch
Patch6:         0006-Remove-bundled-copy-of-sd-daemon.-ch.patch

%description
RealtimeKit is a D-Bus system service that changes the
scheduling policy of user processes/threads to SCHED_RR (i.e. realtime
scheduling mode) on request. It is intended to be used as a secure
mechanism to allow real-time scheduling to be used by normal user
processes.

RealtimeKit can also be used to hand outh high priority
scheduling (i.e. negative nice level) to user processes.

%package doc
Summary:        Doc files for %{name}
Requires:       %{name} = %{epoch}:%{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -n %{name}-%{version} -p1

%build
autoreconf -fvi
%configure --with-systemdsystemunitdir=%{_unitdir}
%make_build
./rtkit-daemon --introspect > org.freedesktop.RealtimeKit1.xml

%install
%make_install
# install for dbus
install -D -m 0644 org.freedesktop.RealtimeKit1.xml %{buildroot}%{_datadir}/dbus-1/interfaces/org.freedesktop.RealtimeKit1.xml

%generate_compatibility_deps

%pre
# Create the rtkit user and group if they don't exist
# Notice that the uid and gid of the rtkit is both 172
getent group rtkit >/dev/null 2>&1 || groupadd -r -g 172 rtkit
getent passwd rtkit >/dev/null 2>&1 || useradd -r -l -u 172 -g rtkit \
        -d /proc \
        -s /sbin/nologin \
        -c "RealtimeKit" \
        rtkit
:;
 
%post
%systemd_post rtkit-daemon.service
dbus-send --system --type=method_call --dest=org.freedesktop.DBus / org.freedesktop.DBus.ReloadConfig >/dev/null 2>&1 || :
 
%preun
%systemd_preun rtkit-daemon.service
 
%postun
%systemd_postun_with_restart rtkit-daemon.service

%files
%license GPL LICENSE
%attr(0755,root,root) %{_sbindir}/rtkitctl
%attr(0755,root,root) %{_libexecdir}/rtkit-daemon
%dir %{abidir}
%{abidir}/rtkitctl-option.list
%{_datadir}/dbus-1/system-services/org.freedesktop.RealtimeKit1.service
%{_datadir}/dbus-1/interfaces/org.freedesktop.RealtimeKit1.xml
%{_datadir}/polkit-1/actions/org.freedesktop.RealtimeKit1.policy
%{_prefix}/lib/systemd/system/rtkit-daemon.service
%{_mandir}/man8/rtkitctl.8.*
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/org.freedesktop.RealtimeKit1.conf

%files doc
%doc README rtkit.c rtkit.h

%changelog
* Thu Jun  8 2023 Liwei Ge <liwei.glw@alibaba-inc.com> -  1:0.11-4
- fix useradd in pre script

* Mon Apr 10 2023 Kun(llfl) <llfl@linux.alibaba.com> -  1:0.11-3
- optimize spec file
- add license description
- optimize description for the package

* Fri Mar 10 2023 Feng Su <sufeng@linux.alibaba.com> - 1:0.11-2
- add doc package
- add abi/api files

* Fri Apr 15 2022 happy_orange <songnannan@linux.alibaba.com> - 1:0.11-1
- Init package from upstream
